'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function toMidfixed({
  midfix,
  config
}) {
  return Object.keys(config).reduce((midfixed, value) => ({ ...midfixed,
    [`${midfix}-${value}`]: config[value]
  }), {});
}

const tailwind = ['1/2', '1/3', '2/3', '1/4', '2/4', '3/4', '1/5', '2/5', '3/5', '4/5', '1/6', '2/6', '3/6', '4/6', '5/6', '1/12', '2/12', '3/12', '4/12', '5/12', '6/12', '7/12', '8/12', '9/12', '10/12', '11/12'];
const baleada = ['2/1', '1/2', '3/2', '1/3', '2/3', '4/3', '5/3', '1/4', '2/4', '3/4', '5/4', '7/4', '1/5', '2/5', '3/5', '4/5', '6/5', '7/5', '8/5', '9/5', '1/6', '2/6', '3/6', '4/6', '5/6', '7/6', '11/6'];

function rem(config) {
  return toMidfixed({
    midfix: 'rem',
    config
  });
}
function em(config) {
  return toMidfixed({
    midfix: 'em',
    config
  });
}
function px(config) {
  return toMidfixed({
    midfix: 'px',
    config
  });
}
function screen(config) {
  return toMidfixed({
    midfix: 'screen',
    config
  });
}
function fractions({
  unit,
  mode = 'baleada'
}) {
  // TODO: validate unit = %|vw|vh
  // TODO: validate mode = baleada|tailwind
  const fractions = mode === 'baleada' ? baleada : tailwind,
        fractionScale = fractions.reduce((scale, fraction) => ({ ...scale,
    [`${fraction}`]: `calc(${fraction} * 100${unit})`
  }), {}),
        isScreen = /^v(?:w|h)$/.test(unit),
        prepared = isScreen ? screen(fractionScale) : fractionScale;
  return { ...prepared,
    [isScreen ? 'screen' : 'full']: `100${unit}`
  };
}
function withoutTailwindFractions(config) {
  const fractions = tailwind,
        keysWithoutFractions = Object.keys(config).filter(key => !fractions.includes(key));
  return keysWithoutFractions.reduce((result, key) => ({ ...result,
    [key]: config[key]
  }), {});
}

exports.em = em;
exports.fractions = fractions;
exports.px = px;
exports.rem = rem;
exports.screen = screen;
exports.withoutTailwindFractions = withoutTailwindFractions;
